==> flutter_mylibrary-0.4.67.tar.gz: lib/base/getx/getx_refresh_list_controller.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_mylibrary/config/const.dart';
import 'package:flutter_mylibrary/http/easy_dio.dart';
import 'package:flutter_mylibrary/http/http_data.dart';
import 'package:flutter_mylibrary/utils/utils.dart';
import 'package:flutter_mylibrary/widget/widget_template.dart';

import '../../flutter_mylibrary.dart';
import '../base_view_state.dart';
import '../request_info.dart';
import 'base_view_state_getx_controller.dart';



///用于下拉刷新，上拉加载的控制类
abstract class GetxRefreshListController<T> extends BaseViewStateGetxController {


  ///自定义第一页页数
  int firstPage() => startPage;

  ///自定义一页数量
  int pageSize() => pageLimit;

  /// 页面数据
  List<T> list = [];

  /// 当前页码
  int _currentPageNum;

  int get currentPageNum => _currentPageNum;


  int _totalNum;

  int get totalNum => _totalNum??0;

  set totalNum(int value) {
    _totalNum = value;
  }


  bool get hasMore => getRequestInfo().useLoadMore?totalNum > list.length? true : false : false;


  onCompleted(List<T> data) {}


  ///---------------------------------------------------数据获取逻辑区-------------------------------------------------------

  void _getData({bool clearData = false, bool clearDataWhenError = false}) async{

    bool requestState = await _request(clearData: clearData, clearDataWhenError: clearDataWhenError);

    if(requestState){
      setIdle();
    }

    refreshController.finishRefresh(success: requestState);
    refreshController.finishLoad(success: requestState, noMore: !hasMore);
  }

  @override
  void onReady() async{
    refresh();
  }


  ///获取数据,返回请求是否成功
  Future<bool> _request({bool clearData = false, bool clearDataWhenError = false}) async{


    beforeRequest();

    RequestInfo requestInfo = getRequestInfo();

    getOtherData();

    HttpData _httpData = await EasyDio().request(
        requestInfo?.method,
        requestInfo?.url,
        data: requestInfo?.data,
        publicMethod: requestInfo?.publicMethod,
    );


    if(isEmpty(_httpData.httpError)){
      ///请求过程没有出错

      try{
        List<T> resData = [];

        if (isNotEmpty(_httpData.data)) {
          resData = _httpData.data is List?List<T>.from(_httpData.data.map((e) => requestInfo?.handleRes(e))).toList() : requestInfo?.handleRes(_httpData.data);
        }


        if (clearData) {
          list.clear();
        }

        if (isNotEmpty(resData)) {
          list.addAll(resData);
        }

        onCompleted(resData);

        if (isEmpty(list)) {
          ///空数据
          errorType = ViewStateErrorType.noDataError;
          setError(
            errorType: errorType,
          );
          _setError(clearDataWhenError, null);
        }
        return true;
      }catch(e){
        onError(e);
        errorType = ViewStateErrorType.jsonParsingError;
        _setError(clearDataWhenError, _httpData.httpError);
        return false;
      }
    }else{
      errorType = ViewStateErrorType.httpError;
      _setError(clearDataWhenError, _httpData.httpError);
      return false;
    }
  }


  void _setError(bool clearDataWhenError, e){
    if(clearDataWhenError){
      list.clear();
    }
    setError(
        errorType: errorType,
        e: e
    );
  }





  ///------------------------------------------------------刷新，上拉加载----------------------------------------------------

  void refresh({bool clearData = true, bool clearDataWhenError = false}) {
    _currentPageNum = firstPage();
    _getData(clearData: clearData, clearDataWhenError: true);
  }


  /// 上拉加载更多
  void loadMore() {
    _currentPageNum = ++_currentPageNum;
    _getData();
  }




  ///------------------------------------------------------下拉刷新控件----------------------------------------------------

  ///获取一个公共的刷新控件(EasyRefresh)
  Widget getEasyRefreshWidget({ViewStateModelWidgetListBuilder<List<T>> widgetListBuilder, ViewStateModelWidgetBuilder<List<T>> builder, Widget emptyWidget, Widget busyWidget, bool showErrorWidget = true, bool showEmptyWidget = true, bool showBusyWidget = true}){
    Widget emptyErrorWidget = buildRefreshNoDataWidget(viewStateModel: this, busyWidget: busyWidget, emptyDataWidget: emptyWidget, showErrorWidget: showErrorWidget, showEmptyWidget: showEmptyWidget, showBusyWidget: showBusyWidget);
    return EasyRefresh.custom(
      enableControlFinishRefresh: true,
      enableControlFinishLoad: true,
      taskIndependence: true,
      emptyWidget: emptyErrorWidget,
      slivers: isNotEmpty(widgetListBuilder)? widgetListBuilder(list) : [
        isEmpty(emptyErrorWidget)? isNotEmpty(builder)? builder(list) : SliverToBoxAdapter(child: Container(),) :SliverToBoxAdapter(child: Container(),),
      ],
      onRefresh: isBusy? null : () async{
        refresh();
      },
      onLoad: (isBusy || !hasMore)? null : () async{
        loadMore();
      },
      controller: refreshController,
    );
  }







}

==> flutter_mylibrary-0.4.74.tar.gz: lib/base/getx/getx_refresh_list_controller.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_mylibrary/config/const.dart';
import 'package:flutter_mylibrary/http/easy_dio.dart';
import 'package:flutter_mylibrary/http/http_data.dart';
import 'package:flutter_mylibrary/utils/utils.dart';
import 'package:flutter_mylibrary/widget/widget_template.dart';

import '../../flutter_mylibrary.dart';
import '../base_view_state.dart';
import '../request_info.dart';
import 'base_view_state_getx_controller.dart';



///用于下拉刷新，上拉加载的控制类
abstract class GetxRefreshListController<T> extends BaseViewStateGetxController {


  ///自定义第一页页数
  int firstPage() => startPage;

  ///自定义一页数量
  int pageSize() => pageLimit;

  /// 页面数据
  List<T> list = [];

  /// 当前页码
  int _currentPageNum;

  int get currentPageNum => _currentPageNum;


  int _totalNum;

  int get totalNum => _totalNum??0;

  set totalNum(int value) {
    _totalNum = value;
  }


  bool get hasMore => getRequestInfo().useLoadMore?totalNum > list.length? true : false : false;


  onCompleted(List<T> data) {}


  ///---------------------------------------------------数据获取逻辑区-------------------------------------------------------

  void _getData({bool clearData = false, bool clearDataWhenError = false}) async{

    bool requestState = await _request(clearData: clearData, clearDataWhenError: clearDataWhenError);

    if(requestState){
      setIdle();
    }

    refreshController.finishRefresh(success: requestState);
    refreshController.finishLoad(success: requestState, noMore: !hasMore);
  }

  @override
  void onReady() async{
    refreshData();
  }


  ///获取数据,返回请求是否成功
  Future<bool> _request({bool clearData = false, bool clearDataWhenError = false}) async{


    beforeRequest();

    RequestInfo requestInfo = getRequestInfo();

    getOtherData();

    HttpData _httpData = await EasyDio().request(
        requestInfo?.method,
        requestInfo?.url,
        data: requestInfo?.data,
        publicMethod: requestInfo?.publicMethod,
    );


    if(isEmpty(_httpData.httpError)){
      ///请求过程没有出错

      try{
        List<T> resData = [];

        if (isNotEmpty(_httpData.data)) {
          resData = _httpData.data is List?List<T>.from(_httpData.data.map((e) => requestInfo?.handleRes(e))).toList() : requestInfo?.handleRes(_httpData.data);
        }


        if (clearData) {
          list.clear();
        }

        if (isNotEmpty(resData)) {
          list.addAll(resData);
        }

        onCompleted(resData);

        if (isEmpty(list)) {
          ///空数据
          errorType = ViewStateErrorType.noDataError;
          setError(
            errorType: errorType,
          );
          _setError(clearDataWhenError, null);
        }
        return true;
      }catch(e){
        onError(e);
        errorType = ViewStateErrorType.jsonParsingError;
        _setError(clearDataWhenError, _httpData.httpError);
        return false;
      }
    }else{
      errorType = ViewStateErrorType.httpError;
      _setError(clearDataWhenError, _httpData.httpError);
      return false;
    }
  }


  void _setError(bool clearDataWhenError, e){
    if(clearDataWhenError){
      list.clear();
    }
    setError(
        errorType: errorType,
        e: e
    );
  }





  ///------------------------------------------------------刷新，上拉加载----------------------------------------------------

  void refreshData({bool clearData = true, bool clearDataWhenError = false}) {
    _currentPageNum = firstPage();
    _getData(clearData: clearData, clearDataWhenError: true);
  }


  /// 上拉加载更多
  void loadMore() {
    _currentPageNum = ++_currentPageNum;
    _getData();
  }




  ///------------------------------------------------------下拉刷新控件----------------------------------------------------

  ///获取一个公共的刷新控件(EasyRefresh)
  Widget getEasyRefreshWidget({ViewStateModelWidgetListBuilder<List<T>> widgetListBuilder, ViewStateModelWidgetBuilder<List<T>> builder, Widget emptyWidget, Widget busyWidget, bool showErrorWidget = true, bool showEmptyWidget = true, bool showBusyWidget = true}){
    Widget emptyErrorWidget = buildRefreshNoDataWidget(viewStateModel: this, busyWidget: busyWidget, emptyDataWidget: emptyWidget, showErrorWidget: showErrorWidget, showEmptyWidget: showEmptyWidget, showBusyWidget: showBusyWidget);
    return EasyRefresh.custom(
      enableControlFinishRefresh: true,
      enableControlFinishLoad: true,
      taskIndependence: true,
      emptyWidget: emptyErrorWidget,
      slivers: isNotEmpty(widgetListBuilder)? widgetListBuilder(list) : [
        isEmpty(emptyErrorWidget)? isNotEmpty(builder)? builder(list) : SliverToBoxAdapter(child: Container(),) :SliverToBoxAdapter(child: Container(),),
      ],
      onRefresh: isBusy? null : () async{
        refreshData();
      },
      onLoad: (isBusy || !hasMore)? null : () async{
        loadMore();
      },
      controller: refreshController,
    );
  }







}
